@@ -26,7 +26,7 @@ from collections import namedtuple
 
 import requests
 from dateutil.parser import parse as dateutil_parser
-from requests.exceptions import ConnectionError, ConnectTimeout
+from requests.exceptions import ConnectionError, Timeout
 
 PY2 = sys.version_info[0] < 3
 
@@ -137,9 +137,6 @@ class BaseAPI(object):
     def __init__(self, api_key, host='localhost', port=8384,
                  timeout=DEFAULT_TIMEOUT, is_https=False, ssl_cert_file=None):
 
-        if is_https and not ssl_cert_file:
-            logger.warning('using https without specifying ssl_cert_file')
-
         if ssl_cert_file:
             if not os.path.exists(ssl_cert_file):
                 raise SyncthingError(
@@ -152,7 +149,7 @@ class BaseAPI(object):
         self.port = port
         self.ssl_cert_file = ssl_cert_file
         self.timeout = timeout
-        self.verify = True if ssl_cert_file else False
+        self.verify = True if ssl_cert_file or is_https else False
         self._headers = {
             'X-API-Key': api_key
         }
@@ -199,7 +196,6 @@ class BaseAPI(object):
                 data=json.dumps(data),
                 params=params,
                 timeout=self.timeout,
-                verify=self.verify,
                 cert=self.ssl_cert_file,
                 headers=headers
             )
@@ -860,7 +856,7 @@ class Events(BaseAPI):
 
             try:
                 data = self.get(using_url, params=params, raw_exceptions=True)
-            except (ConnectTimeout, ConnectionError) as e:
+            except (ConnectionError, Timeout) as e:
                 # swallow timeout errors for long polling
                 data = None
             except Exception as e:
